Skip to contents

Determine which analyses the supplied tables unlock

Usage

available_analyses(x, contrasts = list())

Arguments

x

A deliberation_data() bundle.

contrasts

Optional definitions from define_contrast().

Value

One row per event and analysis with readiness and missing inputs. Readiness describes inputs, not whether every metric is estimable.

Examples

available_analyses(example_deliberation())
#>    event_id          analysis         layer readiness reason contrasts
#> 1      demo            sample        design     ready                0
#> 2      demo        attendance        design     ready                0
#> 3      demo        assignment        design     ready                0
#> 4      demo     participation participation     ready                0
#> 5      demo          exchange      exchange     ready                0
#> 6      demo    responsiveness      exchange     ready                0
#> 7      demo         arguments      exchange     ready                0
#> 8      demo         materials        design     ready                0
#> 9      demo          exposure      exchange     ready                0
#> 10     demo          outcomes      outcomes     ready                0
#> 11     demo     group_effects      outcomes     ready                0
#> 12     demo     randomization      outcomes     ready                0
#> 13     demo  survey_inference      outcomes     ready                0
#> 14     demo         attrition      outcomes     ready                0
#> 15     demo cluster_inference      outcomes     ready                0